module ControlUnit(
    input [6:0] opcode,
    output reg [1:0] aluOp,
    output reg memWrite,
    output reg memRead,
    output reg branch,
    output reg regWrite,
    output reg jump // переход операций JAL и JALR
);
    always @(*) begin
        case (opcode)
            7'b0000011: begin // Load (I-type)
                aluOp = 2'b00;
                memWrite = 0;
                memRead = 1;
                branch = 0;
                regWrite = 1;
                jump = 0;
            end
            7'b0100011: begin // Store (S-type)
                aluOp = 2'b00;
                memWrite = 1;
                memRead = 0;
                branch = 0;
                regWrite = 0;
                jump = 0;
            end
            7'b1100011: begin // Branch (B-type)
                aluOp = 2'b01;
                memWrite = 0;
                memRead = 0;
                branch = 1;
                regWrite = 0;
                jump = 0;
            end
            7'b0110011: begin // R-type
                aluOp = 2'b10;
                memWrite = 0;
                memRead = 0;
                branch = 0;
                regWrite = 1;
                jump = 0;
            end
            7'b1100111: begin // JALR (I-type)
                aluOp = 2'b00; // Используется для вычисления адреса (PC + imm)
                memWrite = 0;
                memRead = 0;
                branch = 0;
                regWrite = 1; // Результат записывается в регистр
                jump = 1; // Указывает на команду перехода
            end
            7'b1101111: begin // JAL (UJ-type)
                aluOp = 2'b00; 
                memWrite = 0;
                memRead = 0;
                branch = 0;
                regWrite = 1; // Результат записывается в регистр
                jump = 1; // Указывает на команду перехода
            end
            7'b0110111: begin // LUI (U-type)
                aluOp = 2'b11; 
                memWrite = 0;
                memRead = 0;
                branch = 0;
                regWrite = 1; // Загружаем значение в регистр
                jump = 0;
            end
            default: begin
                aluOp = 2'b00;
                memWrite = 0;
                memRead = 0;
                branch = 0;
                regWrite = 0;
                jump = 0;
            end
        endcase
    end
endmodule