module RISC_V(
    input clk,
    input reset
);
    // Входы и выходы
    wire [31:0] pc, instr, readData1, readData2, aluResult;
    wire [6:0] opcode;
    wire [4:0] rd, rs1, rs2;
    wire [2:0] funct3;
    wire [6:0] funct7;
    wire [31:0] imm;
    wire memWrite, memRead, regWrite;
    wire branchTaken, jump;
    wire [3:0] aluControl;
    
    // Компоненты процессора
    PCUnit pc_unit (
        .clk(clk),
        .reset(reset),
        .branchTaken(branchTaken),
        .branchAddr(aluResult),
        .pc(pc)
    );

    InstructionMemory instr_mem (
        .addr(pc),
        .instr(instr)
    );

    InstructionDecoder instr_decoder (
        .instr(instr),
        .opcode(opcode),
        .rd(rd),
        .funct3(funct3),
        .rs1(rs1),
        .rs2(rs2),
        .funct7(funct7),
        .imm(imm)
    );

    RegisterFile reg_file (
        .clk(clk),
        .reset(reset),
        .regWrite(regWrite),
        .rs1(rs1),
        .rs2(rs2),
        .rd(rd),
        .writeData(aluResult),
        .readData1(readData1),
        .readData2(readData2)
    );

    ControlUnit control_unit (
        .opcode(opcode),
        .aluOp(aluOp),
        .memWrite(memWrite),
        .memRead(memRead),
        .branch(branch),
        .regWrite(regWrite),
        .jump(jump)
    );

    ALUDecoder alu_decoder (
        .funct7(funct7),
        .funct3(funct3),
        .aluOp(aluOp),
        .aluControl(aluControl)
    );

    ALU alu (
        .srcA(readData1),
        .srcB( (opcode == 7'b0000011 || opcode == 7'b0100011) ? readData2 : imm), // Используем immediate для операций загрузки/сохранения
        .aluControl(aluControl),
        .aluResult(aluResult)
    );

    DataMemory data_memory (
        .clk(clk),
        .addr(aluResult), // Используем результат ALU как адрес
        .writeData(readData2),
        .memWrite(memWrite),
        .memRead(memRead),
        .readData(readData)
    );

    BranchUnit branch_unit (
        .srcA(readData1),
        .srcB(readData2),
        .funct3(funct3),
        .branchTaken(branchTaken)
    );

endmodule